==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/PAGELABEL.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="LANGUAGE" type="{http://schemas.datastream.net/MP_fields}CODE2_Type"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LABELITEMS"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "language",
    "labelitems"
})
@XmlRootElement(name = "PAGELABEL")
public class PAGELABEL {

    @XmlElement(name = "LANGUAGE", required = true)
    protected String language;
    @XmlElement(name = "LABELITEMS", required = true)
    protected LABELITEMS labelitems;

    /**
     * Obtient la valeur de la propriété language.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLANGUAGE() {
        return language;
    }

    /**
     * Définit la valeur de la propriété language.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLANGUAGE(String value) {
        this.language = value;
    }

    /**
     * Obtient la valeur de la propriété labelitems.
     * 
     * @return
     *     possible object is
     *     {@link LABELITEMS }
     *     
     */
    public LABELITEMS getLABELITEMS() {
        return labelitems;
    }

    /**
     * Définit la valeur de la propriété labelitems.
     * 
     * @param value
     *     allowed object is
     *     {@link LABELITEMS }
     *     
     */
    public void setLABELITEMS(LABELITEMS value) {
        this.labelitems = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/PAGELABEL.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="LANGUAGE" type="{http://schemas.datastream.net/MP_fields}CODE2_Type"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LABELITEMS"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "language",
    "labelitems"
})
@XmlRootElement(name = "PAGELABEL")
public class PAGELABEL {

    @XmlElement(name = "LANGUAGE", required = true)
    protected String language;
    @XmlElement(name = "LABELITEMS", required = true)
    protected LABELITEMS labelitems;

    /**
     * Gets the value of the language property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLANGUAGE() {
        return language;
    }

    /**
     * Sets the value of the language property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLANGUAGE(String value) {
        this.language = value;
    }

    /**
     * Gets the value of the labelitems property.
     * 
     * @return
     *     possible object is
     *     {@link LABELITEMS }
     *     
     */
    public LABELITEMS getLABELITEMS() {
        return labelitems;
    }

    /**
     * Sets the value of the labelitems property.
     * 
     * @param value
     *     allowed object is
     *     {@link LABELITEMS }
     *     
     */
    public void setLABELITEMS(LABELITEMS value) {
        this.labelitems = value;
    }

}
